from
The database, one of 'pubchem', 'chembl', 'cas',
'kegg', 'drugbank'.
parallel
An integer, the parallel parameter, indicates how many
process the user would like to use for retrieving
the data (using RCurl), default is 5.
For regular cases, we recommend a number less than 20.