extractDrugGravitationalIndex(molecules, silent = TRUE)TRUE.GRAV.1 - gravitational index of heavy atoms
GRAV.2 - square root of gravitational index of heavy atoms
GRAV.3 - cube root of gravitational index of heavy atoms
GRAVH.1 - gravitational index - hydrogens included
GRAVH.2 - square root of hydrogen-included gravitational index
GRAVH.3 - cube root of hydrogen-included gravitational index
GRAV.4 - grav1 for all pairs of atoms (not just bonded pairs)
GRAV.5 - grav2 for all pairs of atoms (not just bonded pairs)
GRAV.6 - grav3 for all pairs of atoms (not just bonded pairs)
Wessel, M.D. and Jurs, P.C. and Tolan, J.W. and Muskal, S.M. , Prediction of Human Intestinal Absorption of Drug Compounds From Molecular Structure, Journal of Chemical Information and Computer Sciences, 1998, 38:726-735.
sdf = system.file('sysdata/OptAA3d.sdf', package = 'Rcpi')
mol = readMolFromSDF(sdf)
dat = extractDrugGravitationalIndex(mol)
head(dat)
Run the code above in your browser using DataLab